AlbumModel class

Constructors

AlbumModel({required String id, required String name, required int totalTracks, required List<ImageModel> images, required DateTime releaseDate, required List<SimplifiedArtist> artists, required List<String> genres, required int popularity})
AlbumModel.fromJson(String source)
factory
AlbumModel.fromMap(Map<String, dynamic> map)
factory

Properties

artists List<SimplifiedArtist>
final
genres List<String>
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
images List<ImageModel>
final
name String
final
popularity int
final
releaseDate DateTime
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
totalTracks int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() String
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited