SimplifiedAlbum class

Constructors

SimplifiedAlbum({required String id, required String name, required int totalTracks, required List<Market> availableMarkets, required List<ImageModel> images, required List<SimplifiedArtist> artists})
SimplifiedAlbum.fromJson(String source)
factory
SimplifiedAlbum.fromMap(Map<String, dynamic> map)
factory

Properties

artists List<SimplifiedArtist>
final
availableMarkets List<Market>
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
images List<ImageModel>
final
name String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
totalTracks int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() String
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited