Artist class

Constructors

Artist({required String id, required String name, required List<ImageModel> images, required int popularity})
Artist.fromJson(String source)
factory
Artist.fromMap(Map<String, dynamic> map)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
id String
final
images List<ImageModel>
final
name String
final
popularity int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() String
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited