ImageModel class

Constructors

ImageModel({required String url, required int? width, required int? height})
ImageModel.fromJson(String source)
factory
ImageModel.fromMap(Map<String, dynamic> map)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
height int?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
url String
final
width int?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() String
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited