SimplifiedTrack class

Constructors

SimplifiedTrack({required String id, required String name, required List<SimplifiedArtist> artists, required Duration duration, required bool explicit, required List<Market> availableMarkets, required bool isPlayable, required String? previewUrl, required int trackNumber})
SimplifiedTrack.fromJson(String source)
factory
SimplifiedTrack.fromMap(Map<String, dynamic> map)
factory

Properties

artists List<SimplifiedArtist>
final
availableMarkets List<Market>
final
duration Duration
final
explicit bool
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
isPlayable bool
final
name String
final
previewUrl String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
trackNumber int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() String
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited