TrackModel class

Constructors

TrackModel({required String id, required String name, required SimplifiedAlbum album, required List<SimplifiedArtist> artists, required List<Market> availableMarkets, required int discNumber, required Duration duration, required bool explicit, required bool isPlayable, required int popularity, required String? previewUrl, required int trackNumber})
TrackModel.fromJson(String source)
factory
TrackModel.fromMap(Map<String, dynamic> map)
factory

Properties

album SimplifiedAlbum
final
artists List<SimplifiedArtist>
final
availableMarkets List<Market>
final
discNumber int
final
duration Duration
final
explicit bool
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
isPlayable bool
final
name String
final
popularity int
final
previewUrl String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
trackNumber int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() String
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited