SimplifiedPlaylist class
Constructors
-
SimplifiedPlaylist({required String id, required String name, required List<
ImageModel> images, required UserModel owner, required bool public, required String snapshotId, required int totalTracks, required bool collaborative, required String? description}) - SimplifiedPlaylist.fromJson(String source)
-
factory
-
SimplifiedPlaylist.fromMap(Map<
String, dynamic> map) -
factory
Properties
- collaborative → bool
-
final
- description → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
final
-
images
→ List<
ImageModel> -
final
- name → String
-
final
- owner → UserModel
-
final
- public → bool
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- snapshotId → String
-
final
- totalTracks → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → String -
toMap(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited